# (WIP) django-admitad
[![Build Status](https://travis-ci.org/Picasel/django-admitad.svg?branch=master)](https://travis-ci.org/Picasel/django-admitad)
[![codecov](https://codecov.io/gh/Picasel/django-admitad/branch/master/graph/badge.svg)](https://codecov.io/gh/Picasel/django-admitad)
[![Python versions](https://img.shields.io/pypi/pyversions/django-admitad.svg)](https://pypi.python.org/pypi/django-admitad)
[![Pypi](https://img.shields.io/pypi/v/django-admitad.svg)](https://pypi.python.org/pypi/django-admitad)

Приложение для интеграции с Admitad CPA посредством postback-запросов

## Requirements

* [Python 3.7](https://www.python.org/downloads/release/python-370/)
* [Django 2.1.3](https://www.djangoproject.com/)

## Installation
```sh
$ pip install django-admitad
```

## Usage
Will be soon...

## TODO
 * Release stable version
 * Events log via logging & Django model
 * Celery integration
 * Test coverage (>90%)
 
## License
MIT
